Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDavid Williams2013-03-05 19:59:12 +0000
committerDavid Williams2013-03-05 19:59:12 +0000
commitbe5a57f06fe9e58c9b2ef07f72afef3c4fb3dd2d (patch)
tree2062c8dbfac32abe6387f104df096f20fd7b20df
parentcd4c57541e25f11f3c315af1ef9bf4e3416a329d (diff)
downloadeclipse.platform.releng.aggregator-be5a57f06fe9e58c9b2ef07f72afef3c4fb3dd2d.tar.gz
eclipse.platform.releng.aggregator-be5a57f06fe9e58c9b2ef07f72afef3c4fb3dd2d.tar.xz
eclipse.platform.releng.aggregator-be5a57f06fe9e58c9b2ef07f72afef3c4fb3dd2d.zip
[releng] add more logging control. Turn off default debug
-rwxr-xr-xproduction/build-functions.sh57
-rw-r--r--production/build_eclipse_org.shsource9
-rw-r--r--production/master-build.sh1
-rwxr-xr-xproduction/pom-version-updater.sh2
-rw-r--r--production/run-maven-build.sh4
5 files changed, 50 insertions, 23 deletions
diff --git a/production/build_eclipse_org.shsource b/production/build_eclipse_org.shsource
index d556c0c6d..743e517b5 100644
--- a/production/build_eclipse_org.shsource
+++ b/production/build_eclipse_org.shsource
@@ -39,10 +39,11 @@ B_GIT_EMAIL=e4Build@eclipse.org
B_GIT_NAME="E4 Build"
COMMITTER_ID=e4Build
-# comparator=true means verbose=true (gives debug msgs?)
-COMPARATOR=${COMPARATOR:-true}
-UPDATE_BRANDING=true
-FORCE_LOCAL_REPO=false
+# MVN_DEBUG=true means verbose; gives comparator info
+export MVN_DEBUG=${MVN_DEBUG:-false}
+export MVN_QUIET=${MVN_QUIET:-false}
+export UPDATE_BRANDING=true
+export FORCE_LOCAL_REPO=false
# no-bree-libs to experiment
#MAVEN_BREE=-Pno-bree-libs
# Need bree-libs for production builds
diff --git a/production/master-build.sh b/production/master-build.sh
index c481fe234..849bd6ee0 100644
--- a/production/master-build.sh
+++ b/production/master-build.sh
@@ -90,6 +90,7 @@ fn-write-property B_GIT_EMAIL
fn-write-property B_GIT_NAME
fn-write-property COMMITTER_ID
fn-write-property COMPARATOR
+fn-write-property MVN_QUIET
fn-write-property SIGNING
fn-write-property UPDATE_BRANDING
fn-write-property FORCE_LOCAL_REPO
diff --git a/production/pom-version-updater.sh b/production/pom-version-updater.sh
index 5d5df6290..fa6e0ca88 100755
--- a/production/pom-version-updater.sh
+++ b/production/pom-version-updater.sh
@@ -32,7 +32,7 @@ if [ -z "$BUILD_ID" ]; then
BUILD_ID=$(fn-build-id "$BUILD_TYPE" )
fi
-fn-pom-version-updater "$aggDir" "$LOCAL_REPO"
+fn-pom-version-updater "$aggDir" "$LOCAL_REPO" $MVN_DEBUG $MVN_QUIET
RC=$?
if [[ $RC != 0 ]]
then
diff --git a/production/run-maven-build.sh b/production/run-maven-build.sh
index 6c4341b28..8c68f448d 100644
--- a/production/run-maven-build.sh
+++ b/production/run-maven-build.sh
@@ -31,7 +31,7 @@ if [ -z "$BUILD_ID" ]; then
BUILD_ID=$(fn-build-id "$BUILD_TYPE" )
fi
-fn-maven-build-aggregator "$BUILD_ID" "$aggDir" "$LOCAL_REPO" $COMPARATOR $SIGNING $UPDATE_BRANDING $MAVEN_BREE
+fn-maven-build-aggregator "$BUILD_ID" "$aggDir" "$LOCAL_REPO" $COMPARATOR $MVN_QUIET $SIGNING $UPDATE_BRANDING $MAVEN_BREE
exitCode=$?
# first make sure exit code is well formed
@@ -53,7 +53,7 @@ then
else
echo "exitode was not numeric, so will force to 1"
exitrc=1
-fi
+fi
echo "$( basename $0) exiting with exitrc: $exitrc"
exit $exitrc

Back to the top
diff --git a/production/build-functions.sh b/production/build-functions.sh
index 4351a3e69..cbf22c78e 100755
--- a/production/build-functions.sh
+++ b/production/build-functions.sh
@@ -255,7 +255,7 @@ fn-basebuilder-dir ()
}
# USAGE: fn-maven-build-aggregator BUILD_ID REPO_DIR LOCAL_REPO VERBOSE SIGNING UPDATE_BRANDING MAVEN_BREE
# BUILD_ID: I20121116-0700
# REPO_DIR: /shared/eclipse/builds/R4_2_maintenance/gitCache/eclipse.platform.releng.aggregator
# LOCAL_REPO: /shared/eclipse/builds/R4_2_maintenance/localMavenRepo
@@ -267,24 +267,32 @@ fn-maven-build-aggregator ()
BUILD_ID="$1"; shift
REPO_DIR="$1"; shift
LOCAL_REPO="$1"; shift
+ DEBUG=$1; shift
+ QUIET=$1; shift
+ SIGNING=$1; shift
+ UPDATE_BRANDING=$1; shift
+ MAVEN_BREE=$1; shift
+
MARGS="-DbuildId=$BUILD_ID"
- if $VERBOSE; then
+ if $DEBUG; then
MARGS="$MARGS -X"
fi
- shift
+ if $QUIET; then
+ MARGS="$MARGS -q"
+ fi
if $SIGNING; then
MARGS="$MARGS -Peclipse-sign"
fi
- shift
if $UPDATE_BRANDING; then
MARGS="$MARGS -Pupdate-branding-plugins"
fi
- shift
MARGS="$MARGS ${MAVEN_BREE}"
+ echo "DEBUG: Variables in $0"
echo "DEBUG: BUILD_ID: $BUILD_ID"
echo "DEBUG: REPO_DIR: $REPO_DIR"
echo "DEBUG: LOCAL_REPO: $LOCAL_REPO"
- echo "DEBUG: VERBOSE: $VERBOSE"
+ echo "DEBUG: DEBUG: $DEBUG"
+ echo "DEBUG: QUIET: $QUIET"
echo "DEBUG: UPDATE_BRANDING: $UPDATE_BRANDING"
echo "DEBUG: MAVEN_BREE: $MAVEN_BREE"
pushd "$REPO_DIR"
@@ -361,14 +369,29 @@ fn-tag-build-inputs ()
popd
}
-# USAGE: fn-pom-version-updater REPO_DIR LOCAL_REPO
+# USAGE: fn-pom-version-updater REPO_DIR LOCAL_REPO DEBUG QUIET
# REPO_DIR: /shared/eclipse/builds/R4_2_maintenance/gitCache/eclipse.platform.releng.aggregator
# LOCAL_REPO: /shared/eclipse/builds/R4_2_maintenance/localMavenRepo
fn-pom-version-updater ()
{
REPO_DIR="$1"; shift
LOCAL_REPO="$1"; shift
-
+ DEBUG=$1; shift
+ QUIET=$1; shift
+
+ MARGS=""
+ if $DEBUG; then
+ MARGS="$MARGS -X"
+ fi
+ if $QUIET; then
+ MARGS="$MARGS -q"
+ fi
+ echo "DEBUG: Variables in $0"
+ echo "DEBUG: REPO_DIR: $REPO_DIR"
+ echo "DEBUG: LOCAL_REPO: $LOCAL_REPO"
+ echo "DEBUG: DEBUG: $DEBUG"
+ echo "DEBUG: QUIET: $QUIET"
+ echo "DEBUG: MARGS: $MARGS"
# fail fast if not set up correctly
rc=$(fn-check-dir-exists TMP_DIR)
checkForErrorExit "$rc" "$rc"
@@ -382,17 +405,19 @@ fn-pom-version-updater ()
RC=$?
if [[ $RC != 0 ]]
then
- echo "ERROR: tycho-versions-plugin:update-pom returned non-zero return code: $RC"
- return $RC
- fi
- changes=$( git status --short -uno | cut -c4- )
- if [ -z "$changes" ]; then
- echo No changes in pom versions
- return
+ echo "ERROR: tycho-versions-plugin:update-pom returned non-zero return code: $RC" >&2
else
- echo Changes in pom versions
+ changes=$( git status --short -uno | cut -c4- )
+ if [ -z "$changes" ]; then
+ echo "INFO: No changes in pom versions" >&2
+ RC=0
+ else
+ echo "INFO: Changes in pom versions: $changes" >&2
+ RC=0
+ fi
fi
popd
+ return $RC
}
# USAGE: fn-pom-version-update-with-commit BUILD_ID REPO_DIR LOCAL_REPO
@@ -255,7 +255,7 @@ fn-basebuilder-dir ()
}
-# USAGE: fn-maven-build-aggregator BUILD_ID REPO_DIR LOCAL_REPO VERBOSE SIGNING UPDATE_BRANDING MAVEN_BREE
+# USAGE: fn-maven-build-aggregator BUILD_ID REPO_DIR LOCAL_REPO DEBUG QUIET SIGNING UPDATE_BRANDING MAVEN_BREE
# BUILD_ID: I20121116-0700
# REPO_DIR: /shared/eclipse/builds/R4_2_maintenance/gitCache/eclipse.platform.releng.aggregator